# -*- coding: utf-8 -*-
#
# Copyright 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Test Ubunto SSO Wizard."""

from twisted.internet import defer

from ubuntu_sso.qt import ubuntu_sso_wizard
from ubuntu_sso.qt.tests import BaseTestCase


class ReturnCodeTestCase(BaseTestCase):
    """Test the return codes."""

    @defer.inlineCallbacks
    def setUp(self):
        yield super(ReturnCodeTestCase, self).setUp()
        self.patch(ubuntu_sso_wizard.sys, 'exit', self._set_called)
        self.app_name = 'app_name'
        self.ui = ubuntu_sso_wizard.UbuntuSSOWizard(self.app_name)

    def test_closing_main_window(self):
        """When closing the main window, USER_CANCELLATION is returned."""
        self.ui.close()
        self.assertEqual(self._called,
            ((ubuntu_sso_wizard.USER_CANCELLATION,), {}))

    # pylint: disable=W0212
    def test_close_wizard_reaching_success_page(self):
        """Closing the window in success page, USER_SUCCESS is returned."""
        email = 'email@example.com'
        self.ui._move_to_success_page(self.app_name, email)
        self.ui.close()
        self.assertEqual(self._called,
            ((ubuntu_sso_wizard.USER_SUCCESS,), {}))
    # pylint: enable=W0212
